﻿Imports System.Net
Imports System.Windows
Imports System.Windows.Controls
Imports System.Windows.Documents
Imports System.Windows.Input
Imports System.Windows.Media
Imports System.Windows.Media.Animation
Imports System.Windows.Shapes
Imports System.Collections.ObjectModel
Imports System.Xml.Linq
Imports System.Runtime.InteropServices.Automation

Namespace SilverlightApplication51
	Partial Public Class MainPage
		Inherits UserControl
		Public Sub New()
			InitializeComponent()

			AddHandler Loaded, AddressOf MainPage_Loaded
		End Sub

		Private Sub MainPage_Loaded(ByVal sender As Object, ByVal e As RoutedEventArgs)
			TweetList.ItemsSource = _tweets

			Export.IsEnabled = AutomationFactory.IsAvailable
		End Sub

		Private _tweets As New ObservableCollection(Of Tweet)()

		Private Sub GetTweets_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
			Dim client As New WebClient()

            AddHandler client.DownloadStringCompleted, AddressOf OnDownloadStringCompleted

			client.DownloadStringAsync(New Uri("http://search.twitter.com/search.atom?q=silverlight"))
		End Sub
		
        Private Sub OnDownloadStringCompleted(ByVal s As Object, ByVal ea As DownloadStringCompletedEventArgs)
            Dim doc As XDocument = XDocument.Parse(ea.Result)
            Dim ns As XNamespace = "http://www.w3.org/2005/Atom"

            Dim items = From item In doc.Descendants(ns + "entry") _
                        Select New Tweet() With
                               {
                                   .Title = item.Element(ns + "title").Value,
                                   .Image = New Uri((
                                        From xe As XElement In item.Descendants(ns + "link")
                                        Where xe.Attribute("type").Value = "image/png"
                                        Select xe.Attribute("href").Value).First()),
                                   .Link = New Uri((
                                        From xe As XElement In item.Descendants(ns + "link")
                                        Where xe.Attribute("type").Value = "text/html"
                                        Select xe.Attribute("href").Value).First())
                               }

            For Each t As Tweet In items
                _tweets.Add(t)
            Next t
        End Sub

		Private Sub Export_Click(ByVal sender As Object, ByVal e As RoutedEventArgs)
			If _tweets.Count = 0 Then
				MessageBox.Show("No tweets to export. Please get latest tweets first.")
				Return
			End If

			Try
                Dim excel As Object = AutomationFactory.CreateObject("Excel.Application")

				excel.workbooks.Add()

                Dim sheet As Object = excel.ActiveSheet

				Dim row As Integer = 1

				' headers
                Dim linkHeaderCell As Object = sheet.Cells(row, 1)
                Dim textHeaderCell As Object = sheet.Cells(row, 2)

				linkHeaderCell.Value = "Url"
				textHeaderCell.Value = "Message Text"

				' rows
				For Each t As Tweet In _tweets
					row += 1

                    Dim linkCell As Object = sheet.Cells(row, 1)
                    Dim textCell As Object = sheet.Cells(row, 2)

					linkCell.Value = t.Link.ToString()
					textCell.Value = t.Title
				Next t

				excel.Visible = True

			Catch ex As Exception
				MessageBox.Show("Error automating Excel: " & ex.Message)
			End Try
		End Sub
	End Class
End Namespace
